@@ -26,23 +26,17 @@
 #define GTK_DISABLE_DEPRECATED
 #endif
 
-
-#if !defined(WIN32)
 #include <gkrellm2/gkrellm.h>
-#else
-#include <src/gkrellm.h>
-#include <src/win32-plugin.h>
+
+#if defined(WIN32)
 #define F_RDLCK 0
-#define S_IRUSR 0
-#define S_IWUSR 0
-#define S_IXUSR 0
 #define F_WRLCK 0
 #endif
 
 #include <errno.h>
 
 static gchar *str_title = "gkrellm-reminder";
-static gchar *str_version = "2.0.0";
+static gchar *str_version = "2.1.0";
 static gchar *str_date = "12/3/2002";
 static gchar *str_copyright = "Copyright (c) 2001, 2002";
 static gchar *str_author = "James Simonsen";
@@ -313,8 +307,8 @@ reminder_load_stored()
 
   if( reminder_lock_db( fp, F_RDLCK ) )
     {
-      gkrellm_message_window( str_title,
-          "ERROR: Unable to lock event database for reading.", NULL );
+      gkrellm_message_dialog( str_title,
+          "ERROR: Unable to lock event database for reading." );
       return;
     }
 
@@ -385,7 +379,7 @@ reminder_save_stored()
 	  slash = strrchr( dir, '/' );
 	  if( !slash )
 	    {
-	      gkrellm_message_window( str_title, "ERROR: Unable to create event database.", NULL );
+	      gkrellm_message_dialog( str_title, "ERROR: Unable to create event database." );
 	      return;
 	    }
 	  *slash = '\0';
@@ -399,20 +393,20 @@ reminder_save_stored()
 	  fp = fopen( config.event_file, "w" );
 	  if( !fp )
 	    {
-	      gkrellm_message_window( str_title, "ERROR: Unable to open event database for writing.", NULL );
+	      gkrellm_message_dialog( str_title, "ERROR: Unable to open event database for writing." );
 	      return;
 	    }
 	}
       else
 	{
-	  gkrellm_message_window( str_title, "ERROR: Unable to open event database for writing.", NULL );
+	  gkrellm_message_dialog( str_title, "ERROR: Unable to open event database for writing." );
 	  return;
 	}
     }
 
   if( reminder_lock_db( fp, F_WRLCK ) )
     {
-      gkrellm_message_window( str_title, "ERROR: Unable to lock event database for writing.", NULL );
+      gkrellm_message_dialog( str_title, "ERROR: Unable to lock event database for writing." );
       return;
     }
 
@@ -423,7 +417,7 @@ reminder_save_stored()
 #else
   if( ftruncate( fileno( fp ), 0 ) )
     {
-      gkrellm_message_window( str_title, "ERROR: Unable to truncate event database.", NULL );
+      gkrellm_message_dialog( str_title, "ERROR: Unable to truncate event database." );
       return;
     }
 #endif
@@ -1003,8 +997,8 @@ reminder_build_today( gboolean rebuild )
 static void
 cb_set_days( GtkWidget *window, gpointer data )
 {
-  gint weekdays = (gint) data & 1;
-  gint weekends = (gint) data & 2;
+  gint weekdays = GPOINTER_TO_INT(data) & 1;
+  gint weekends = GPOINTER_TO_INT(data) & 2;
 
   gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( check_sun ), weekends );
   gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( check_sat ), weekends );
@@ -1102,13 +1096,13 @@ reminder_get_days_string( struct event_stored *current )
       int day = current->days & 31;
       int month = current->days >> 16;
 
-      if( day % 10 == 1 )
+      if( day % 10 == 1 && day != 11)
 	//pos = sprintf( string, "%dst", day );
         string = g_strdup_printf("%dst", day );
-      else if( day % 10 == 2 )
+      else if( day % 10 == 2 && day != 12)
 	//pos = sprintf( string, "%dnd", day );
         string = g_strdup_printf("%dnd", day );
-      else if( day % 10 == 3 )
+      else if( day % 10 == 3 && day != 13)
 	//pos = sprintf( string, "%drd", day );
         string = g_strdup_printf("%drd", day );
       else
@@ -1140,7 +1134,7 @@ reminder_ui_to_event_stored( struct event_stored *current )
   name = (gchar *) gtk_entry_get_text( GTK_ENTRY( entry_event ) );
   if( strlen( name ) < 1 )
     {
-      gkrellm_message_window( str_title, "ERROR: You must enter a name for this event.", entry_event );
+      gkrellm_message_dialog( str_title, "ERROR: You must enter a name for this event." );
       return NULL;
     }
 //  current->name = malloc( strlen( name ) );
@@ -1185,7 +1179,7 @@ reminder_ui_to_event_stored( struct event_stored *current )
 
   if( current->end < current->start && current->end != FOREVER )
     {
-      gkrellm_message_window( str_title, "ERROR: End date can't be smaller than start date.", spin_start_day );
+      gkrellm_message_dialog( str_title, "ERROR: End date can't be smaller than start date." );
 
       g_free( current->name );
       return NULL;
@@ -1211,7 +1205,7 @@ reminder_ui_to_event_stored( struct event_stored *current )
 
       if( !current->days )
 	{
-	  gkrellm_message_window( str_title, "ERROR: You must select at least one day.", check_sun );
+	  gkrellm_message_dialog( str_title, "ERROR: You must select at least one day." );
 	  g_free( current->name );
 	  return NULL;
 	}
@@ -1261,12 +1255,12 @@ cb_add_entry( struct event_stored *event, gint row )
   if( row == -1 )
     {
       row = gtk_clist_append( GTK_CLIST( list_main ), array );
-      gtk_clist_set_row_data( GTK_CLIST( list_main ), row, (gpointer) event->id );
+      gtk_clist_set_row_data( GTK_CLIST( list_main ), row, GUINT_TO_POINTER(event->id) );
     }
   else
     {
       gtk_clist_insert( GTK_CLIST( list_main ), row, array );
-      gtk_clist_set_row_data( GTK_CLIST( list_main ), row, (gpointer) event->id );
+      gtk_clist_set_row_data( GTK_CLIST( list_main ), row, GUINT_TO_POINTER(event->id) );
     }
 
   gtk_clist_columns_autosize( GTK_CLIST( list_main ) );
@@ -1388,7 +1382,7 @@ cb_remove( GtkWidget *window, gpointer data )
   if( list_main_row_selected == -1 )
     return;
 
-  id = (guint) gtk_clist_get_row_data( GTK_CLIST( list_main ), list_main_row_selected );
+  id = GPOINTER_TO_UINT(gtk_clist_get_row_data( GTK_CLIST( list_main ), list_main_row_selected ));
 
   /* Try to remove event from temp list. If not, add to to-be-deleted list */
   if( !reminder_remove_event_stored( &head_temp, id ) )
@@ -1661,13 +1655,13 @@ cb_sort_days( GtkCList *clist, gconstpointer *p1, gconstpointer *p2 )
 
   struct event_stored *es1, *es2;
 
-  es1 = reminder_find_event_stored( head_stored, (guint) row1->data );
+  es1 = reminder_find_event_stored( head_stored, GPOINTER_TO_UINT(row1->data) );
   if( !es1 )
-    es1 = reminder_find_event_stored( head_temp, (guint) row1->data );
+    es1 = reminder_find_event_stored( head_temp, GPOINTER_TO_UINT(row1->data) );
 
-  es2 = reminder_find_event_stored( head_stored, (guint) row2->data );
+  es2 = reminder_find_event_stored( head_stored, GPOINTER_TO_UINT(row2->data) );
   if( !es2 )
-    es2 = reminder_find_event_stored( head_temp, (guint) row2->data );
+    es2 = reminder_find_event_stored( head_temp, GPOINTER_TO_UINT(row2->data) );
 
   if( es1 && es2 )
     {
@@ -1692,13 +1686,13 @@ cb_sort_time( GtkCList *clist, gconstpointer *p1, gconstpointer *p2 )
 
   struct event_stored *es1, *es2;
 
-  es1 = reminder_find_event_stored( head_stored, (guint) row1->data );
+  es1 = reminder_find_event_stored( head_stored, GPOINTER_TO_UINT(row1->data) );
   if( !es1 )
-    es1 = reminder_find_event_stored( head_temp, (guint) row1->data );
+    es1 = reminder_find_event_stored( head_temp, GPOINTER_TO_UINT(row1->data) );
 
-  es2 = reminder_find_event_stored( head_stored, (guint) row2->data );
+  es2 = reminder_find_event_stored( head_stored, GPOINTER_TO_UINT(row2->data) );
   if( !es2 )
-    es2 = reminder_find_event_stored( head_temp, (guint) row2->data );
+    es2 = reminder_find_event_stored( head_temp, GPOINTER_TO_UINT(row2->data) );
 
   if( es1 && es2 )
     return( ( ( es1->start - TIMEZONE_DIFF ) % SECS_PER_DAY ) -
@@ -1715,13 +1709,13 @@ cb_sort_start( GtkCList *clist, gconstpointer *p1, gconstpointer *p2 )
 
   struct event_stored *es1, *es2;
 
-  es1 = reminder_find_event_stored( head_stored, (guint) row1->data );
+  es1 = reminder_find_event_stored( head_stored, GPOINTER_TO_UINT(row1->data) );
   if( !es1 )
-    es1 = reminder_find_event_stored( head_temp, (guint) row1->data );
+    es1 = reminder_find_event_stored( head_temp, GPOINTER_TO_UINT(row1->data) );
 
-  es2 = reminder_find_event_stored( head_stored, (guint) row2->data );
+  es2 = reminder_find_event_stored( head_stored, GPOINTER_TO_UINT(row2->data) );
   if( !es2 )
-    es2 = reminder_find_event_stored( head_temp, (guint) row2->data );
+    es2 = reminder_find_event_stored( head_temp, GPOINTER_TO_UINT(row2->data) );
 
   if( es1 && es2 )
     return es1->start - es2->start;
@@ -1737,13 +1731,13 @@ cb_sort_end( GtkCList *clist, gconstpointer *p1, gconstpointer *p2 )
 
   struct event_stored *es1, *es2;
 
-  es1 = reminder_find_event_stored( head_stored, (guint) row1->data );
+  es1 = reminder_find_event_stored( head_stored, GPOINTER_TO_UINT(row1->data) );
   if( !es1 )
-    es1 = reminder_find_event_stored( head_temp, (guint) row1->data );
+    es1 = reminder_find_event_stored( head_temp, GPOINTER_TO_UINT(row1->data) );
 
-  es2 = reminder_find_event_stored( head_stored, (guint) row2->data );
+  es2 = reminder_find_event_stored( head_stored, GPOINTER_TO_UINT(row2->data) );
   if( !es2 )
-    es2 = reminder_find_event_stored( head_temp, (guint) row2->data );
+    es2 = reminder_find_event_stored( head_temp, GPOINTER_TO_UINT(row2->data) );
 
   if( es1 && es2 )
     return es1->end - es2->end;
@@ -2884,7 +2878,7 @@ reminder_text_button_enable( void )
 static void
 reminder_window_never( GtkWidget *window, gpointer data )
 {
-  guint id = (guint) data;
+  const guint id = GPOINTER_TO_UINT(data);
 
   /* delete event from today */
   num_active--;
@@ -2914,7 +2908,7 @@ reminder_window_never( GtkWidget *window, gpointer data )
 static void
 reminder_window_later( GtkWidget *window, gpointer data )
 {
-  guint id = (guint) data;
+  const guint id = GPOINTER_TO_UINT(data);
   struct event_stored *new, *old;
 
   /* delete event from today */
@@ -2991,7 +2985,7 @@ reminder_window_later( GtkWidget *window, gpointer data )
 static void
 reminder_window_dismiss( GtkWidget *window, gpointer data )
 {
-  guint id = (guint) data;
+  const guint id = GPOINTER_TO_UINT(data);
 
   /* delete event from today */
   num_active--;
@@ -3181,12 +3175,12 @@ reminder_draw_panel_text( gint num_active, gint num_today )
 
   ts_old = ts = reminder_text_decal->text_style;
 
-  w = gdk_string_width( ts.font, buf );
+  w = gkrellm_gdk_string_width( ts.font, buf );
 
   if( w > reminder_text_decal->w )
     {
       ts.font = gkrellm_meter_alt_textstyle( style_id )->font;
-      w = gdk_string_width( ts.font, buf );
+      w = gkrellm_gdk_string_width( ts.font, buf );
     }
 
   style = gkrellm_meter_style( style_id );
@@ -3371,17 +3365,11 @@ static GkrellmMonitor	reminder_monitor	=
 };
 
 #if defined(WIN32)
-    __declspec(dllexport) GkrellmMonitor *
-    gkrellm_init_plugin(win32_plugin_callbacks* calls)
-#else
-    GkrellmMonitor *
-    gkrellm_init_plugin()
+__declspec(dllexport)
 #endif
+GkrellmMonitor *
+gkrellm_init_plugin()
 {
-#if defined(WIN32)
-    callbacks = calls;
-#endif
-
     pGK = gkrellm_ticks();
 
     reminder_mon = &reminder_monitor;
